==> kdp-api-python-client-0.16.5.tar.gz: kdp-api-python-client-0.16.5/kdp_api/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.ingest_api import IngestApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from kdp_api.api.ingest_api import IngestApi
from kdp_api.api.query_api import QueryApi
from kdp_api.api.read_api import ReadApi
from kdp_api.api.write_api import WriteApi
from kdp_api.api.abac_label_parsers_api import AbacLabelParsersApi
from kdp_api.api.applications_api import ApplicationsApi
from kdp_api.api.attribute_assignments_api import AttributeAssignmentsApi
from kdp_api.api.attributes_api import AttributesApi
from kdp_api.api.authentication_api import AuthenticationApi
from kdp_api.api.daily_usage_api import DailyUsageApi
from kdp_api.api.dataset_permissions_api import DatasetPermissionsApi
from kdp_api.api.datasets_api import DatasetsApi
from kdp_api.api.group_memberships_api import GroupMembershipsApi
from kdp_api.api.groups_api import GroupsApi
from kdp_api.api.indexes_api import IndexesApi
from kdp_api.api.jobs_api import JobsApi
from kdp_api.api.reported_usage_api import ReportedUsageApi
from kdp_api.api.segments_api import SegmentsApi
from kdp_api.api.source_types_api import SourceTypesApi
from kdp_api.api.usage_api import UsageApi
from kdp_api.api.users_api import UsersApi
from kdp_api.api.workspace_invitations_api import WorkspaceInvitationsApi
from kdp_api.api.workspace_management_api import WorkspaceManagementApi
from kdp_api.api.workspaces_api import WorkspacesApi

==> kdp-api-python-client-0.35.0.tar.gz: kdp-api-python-client-0.35.0/kdp_api/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.abac_label_parsers_api import AbacLabelParsersApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from kdp_api.api.abac_label_parsers_api import AbacLabelParsersApi
from kdp_api.api.applications_api import ApplicationsApi
from kdp_api.api.attribute_assignments_api import AttributeAssignmentsApi
from kdp_api.api.attributes_api import AttributesApi
from kdp_api.api.authentication_api import AuthenticationApi
from kdp_api.api.dataset_permissions_api import DatasetPermissionsApi
from kdp_api.api.datasets_api import DatasetsApi
from kdp_api.api.group_memberships_api import GroupMembershipsApi
from kdp_api.api.groups_api import GroupsApi
from kdp_api.api.indexes_api import IndexesApi
from kdp_api.api.ingest_api import IngestApi
from kdp_api.api.jobs_api import JobsApi
from kdp_api.api.query_api import QueryApi
from kdp_api.api.read_api import ReadApi
from kdp_api.api.reindex_api import ReindexApi
from kdp_api.api.segments_api import SegmentsApi
from kdp_api.api.source_types_api import SourceTypesApi
from kdp_api.api.users_api import UsersApi
from kdp_api.api.workspace_invitations_api import WorkspaceInvitationsApi
from kdp_api.api.workspace_management_api import WorkspaceManagementApi
from kdp_api.api.workspaces_api import WorkspacesApi
from kdp_api.api.write_api import WriteApi
